#!/bin/bash

usage() {
    cat <<-EOF
	usage: $SCRIPT_NAME [OPTIONS]...
	Copy image to SD-card

	OPTIONS:
	  -d DEV      device ${DEV/*/(default=$DEV)}
	  -i IMAGE    image ${IMAGE/*/(default=$IMAGE)}
	  -h          help
EOF
}

set -e

SCRIPT_HOME=$(cd $(dirname ${BASH_SOURCE[0]}) && pwd)
SCRIPT_NAME=$(basename ${BASH_SOURCE[0]})

DEV=/dev/sdb
IMAGE=$(cd $SCRIPT_HOME && ls -r *.sdcard 2>/dev/null | head -n 1)

# Parse command line
while [ $# -gt 0 ]; do
    case "$1" in
	-d) shift; DEV=$1;;
	-i) shift; IMAGE=$1;;
	-h|--help) usage; exit 0;;
	*)         usage; exit 1;;
    esac
    shift
done

if [ -z "$IMAGE" ]; then
    usage
    exit 1
fi

read -p "insert SD-card into PC [Y/n] : " ANSWER
case "$ANSWER" in
    n|N|no|NO) exit 0;;
    *);;
esac

umount $DEV[0-9]* 2>/dev/null || true

read -p "copy IMAGE=$IMAGE to $DEV [y/N] : " ANSWER
case "$ANSWER" in
    y|Y|yes|YES);;
    *) exit 0;;
esac

echo sudo dd if=$IMAGE of=$DEV
sudo dd if=$IMAGE of=$DEV

echo "done"
